@@ -6,7 +6,7 @@
 #' expression on the rows and a selection of variables on the columns.
 #' @param file character local filename to write to
 #' @param format character export format: currently supported values are "csv"
-#' and "spss".
+#' and "spss" (and experimental support for "parquet").
 #' @param categorical character: export categorical values to CSV as category
 #' "name" (default) or "id". Ignored by the SPSS exporter.
 #' @param na Similar to the argument in [utils::write.table()], 'na'
@@ -32,12 +32,25 @@
 #' @aliases write.csv
 #'
 #' @return Invisibly, `file`.
+#' @examples
+#' \dontrun{
+#' csv_file <- exportDataset(ds, "data.csv")
+#' data <- read.csv(csv_file)
+#'
+#' # parquet will likely read more quickly and be a smaller download size
+#' parquet_file <- exportDataset(ds, "data.parquet")
+#' # data <- arrow::read_parquet(parquet_file) # The arrow package can read parquet files
+#' }
 #' @export
-exportDataset <- function(dataset, file, format = c("csv", "spss"),
+exportDataset <- function(dataset, file, format = c("csv", "spss", "parquet"),
                           categorical = c("name", "id"), na = NULL,
                           varlabel = c("name", "description"),
                           include.hidden = FALSE, ...) {
     exporters <- crGET(shojiURL(dataset, "views", "export"))
+    # --- match.arg gets made when there are multiple given and they don't match
+    # --- exactly to the choices. Since choices comes from the API choose the
+    # --- first if it's longer than 1 before sending to match.arg
+    if (length(format) > 1) format <- format[1]
     format <- match.arg(format, choices = names(exporters))
     export_url <- exporters[[format]]
 
