@@ -118,15 +118,19 @@ collateCats <- function(inserts, var_cats) {
 # for a single Insertion, and a set of categories (or collated categories and
 # insertions) find the position to insert to
 findInsertPosition <- function(insert, cats) {
-    anchr <- anchor(insert)
+    anchr <- anchor(insert, var_items = cats)
+
     # if the anchor is top, put at the beginning
     if (anchr == "top") {
         return(0)
     }
 
     # if the anchor is the id of a non-missing category put it after that cat
-    if (anchr %in% ids(cats)) {
-        which_cat <- which(anchr == ids(cats))
+    # But don't use the ids from the non-categories (eg insertions) because
+    # anchors are only to categories
+    cat_ids <- ifelse(vapply(cats, is.category, logical(1)), ids(cats), NA)
+    if (anchr %in% cat_ids) {
+        which_cat <- which(anchr == cat_ids)
         if (!is.na(cats[[which_cat]])) {
             return(which_cat)
         }
