@@ -1,7 +1,7 @@
 context("changeCategoryID")
 
 with_mock_crunch({
-    ds <- loadDataset("test ds")
+    ds <- cachedLoadDataset("test ds")
 
     test_that("changeCategoryID input validation", {
         expect_error(
