@@ -22,7 +22,7 @@ test_that("cube missing functions set @useNA", {
 })
 
 with_mock_crunch({
-    ds <- loadDataset("test ds")
+    ds <- cachedLoadDataset("test ds")
 
     test_that("formulaToCubeQuery", {
         expect_identical(
@@ -490,4 +490,29 @@ with_test_authentication({
     test_that("Univariate stats", {
         expect_equivalent(as.array(crtabs(mean(v3) ~ 1, data = ds)), 17.5)
     })
+
+    test_that("scorecard query works", {
+        # Setup a dataset for scorecards
+        ds_scorecard <- newDataset(
+            data.frame(
+                x1 = factor(c("a", "b", "c", "a", "c"), letters[1:3]),
+                x2 = factor(c("c", "c", "b", "c", "b"), letters[1:3])
+            ),
+            "scorecard test"
+        )
+        ds_scorecard$x_sel_a <- deriveArray(
+            ds_scorecard[c("x1", "x2")], "x mr - a", selections = "a"
+        )
+        ds_scorecard$x_sel_b <- deriveArray(
+            ds_scorecard[c("x1", "x2")], "x mr - b", selections = "b"
+        )
+
+        scorecard_cube <- crtabs(~scorecard(x_sel_a, x_sel_b), ds_scorecard)
+
+        expect_equal(dimnames(scorecard_cube)[[1]], c("x1", "x2"))
+        expect_equal(dimnames(scorecard_cube)[[2]], c("x mr - a", "x mr - b"))
+        scorecard_values <- as.array(scorecard_cube)
+        dimnames(scorecard_values) <- NULL
+        expect_equal(scorecard_values, matrix(c(2, 0, 1, 2), ncol = 2))
+    })
 })
