@@ -1,7 +1,7 @@
 context("Variable types")
 
 with_mock_crunch({
-    ds <- loadDataset("test ds")
+    ds <- cachedLoadDataset("test ds")
 
     test_that("Variable type method", {
         expect_identical(type(ds[["birthyr"]]), "numeric")
